@@ -5,11 +5,14 @@ from herre.auth import HerreClient
 
 
 class ArkitektConfig(BaseConfig):
-    _group = "arkitekt"
     host: str
     port: int
     secure: bool
 
+    class Config:
+        yaml_group = "arkitekt"
+        env_prefix = "arkitekt_"
+
 
 class ArkitektWard(GraphQLWard):
 
